import { Component, For } from 'solid-js';
import { peekCachedSignal } from '../../workers/cached-signals';
import { RteViewer } from '../rte';
import Tree from '../tree';
import { TrkViewer } from '../trk';
import { WptViewer } from '../wpt';
import GpxIcon from './GpxIcon';

interface Props {
  gpxId: string;
  restrictToHierarchy?: any;
}

const GpxViewer: Component<Props> = ({ gpxId, restrictToHierarchy }) => {
  const gpx = peekCachedSignal({ id: gpxId, action: 'getGpx' });
  console.log({ caller: 'GpxViewer', gpxId, restrictToHierarchy, gpx: gpx() });
  const title = () => {
    return gpx().metadata.name;
  };

  return (
    <Tree
      title={
        <>
          <span>
            {' '}
            <GpxIcon /> {title()}
          </span>
        </>
      }
      content={undefined}
      subTree={
        <For
          each={Object.keys(restrictToHierarchy).filter(
            (key: string) =>
              key.startsWith('gpx/') &&
              (gpx().trk?.includes(key) ||
                gpx().wpt?.includes(key) ||
                gpx().rte?.includes(key))
          )}
        >
          {(key: string) => {
            const child = restrictToHierarchy[key];
            if (child.type === 'wpt') {
              return <WptViewer wptId={key} />;
            }
            if (child.type === 'rte') {
              return <RteViewer rteId={key} />;
            }
            if (child.type === 'trk') {
              return <TrkViewer trkId={key} restrictToHierarchy={child} />;
            }
            return <></>;
          }}
        </For>
      }
    />
  );
};

export default GpxViewer;
